@@ -190,8 +190,9 @@ def form_info(state):
 
     # Add the parent field into the final paremeters used to generate the
     # page query string.
-    params[parent_field] = parent_value
+    params[parent_field] = [parent_value]
 
+    form_info['paging_params'] = params
     form_info['paging_query_string'] = urlencode(params, True)
 
     # Determine if there are any visible fields in the form that are not part
